Class: Google::Apis::MigrationcenterV1::BiosDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Details about the BIOS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiosDetails

Returns a new instance of BiosDetails.



1045
1046
1047
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bios_nameString

BIOS name. This fields is deprecated. Please use the id field instead. Corresponds to the JSON property biosName

Returns:

  • (String)


1011
1012
1013
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1011

def bios_name
  @bios_name
end

#idString

BIOS ID. Corresponds to the JSON property id

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1016

def id
  @id
end

#manufacturerString

BIOS manufacturer. Corresponds to the JSON property manufacturer

Returns:

  • (String)


1021
1022
1023
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1021

def manufacturer
  @manufacturer
end

#release_dateGoogle::Apis::MigrationcenterV1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property releaseDate



1033
1034
1035
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1033

def release_date
  @release_date
end

#smbios_uuidString

SMBIOS UUID. Corresponds to the JSON property smbiosUuid

Returns:

  • (String)


1038
1039
1040
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1038

def smbios_uuid
  @smbios_uuid
end

#versionString

BIOS version. Corresponds to the JSON property version

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1043

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1050
1051
1052
1053
1054
1055
1056
1057
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1050

def update!(**args)
  @bios_name = args[:bios_name] if args.key?(:bios_name)
  @id = args[:id] if args.key?(:id)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @release_date = args[:release_date] if args.key?(:release_date)
  @smbios_uuid = args[:smbios_uuid] if args.key?(:smbios_uuid)
  @version = args[:version] if args.key?(:version)
end