Class: Google::Apis::MigrationcenterV1::ComputeEnginePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

The user preferences relating to Compute Engine target platform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeEnginePreferences

Returns a new instance of ComputeEnginePreferences.



1148
1149
1150
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#license_typeString

License type to consider when calculating costs for virtual machine insights and recommendations. If unspecified, costs are calculated based on the default licensing plan. Corresponds to the JSON property licenseType

Returns:

  • (String)


1133
1134
1135
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1133

def license_type
  @license_type
end

#machine_preferencesGoogle::Apis::MigrationcenterV1::MachinePreferences

The type of machines to consider when calculating virtual machine migration insights and recommendations. Not all machine types are available in all zones and regions. Corresponds to the JSON property machinePreferences



1140
1141
1142
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1140

def machine_preferences
  @machine_preferences
end

#persistent_disk_typeString

Persistent disk type to use. If unspecified (default), all types are considered, based on available usage data. Corresponds to the JSON property persistentDiskType

Returns:

  • (String)


1146
1147
1148
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1146

def persistent_disk_type
  @persistent_disk_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1153
1154
1155
1156
1157
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1153

def update!(**args)
  @license_type = args[:license_type] if args.key?(:license_type)
  @machine_preferences = args[:machine_preferences] if args.key?(:machine_preferences)
  @persistent_disk_type = args[:persistent_disk_type] if args.key?(:persistent_disk_type)
end