Class: Google::Apis::MigrationcenterV1::DailyResourceUsageAggregation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Usage data aggregation for a single day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyResourceUsageAggregation

Returns a new instance of DailyResourceUsageAggregation.



1321
1322
1323
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpuGoogle::Apis::MigrationcenterV1::DailyResourceUsageAggregationCpu

Statistical aggregation of CPU usage. Corresponds to the JSON property cpu



1292
1293
1294
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1292

def cpu
  @cpu
end

#dateGoogle::Apis::MigrationcenterV1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



1304
1305
1306
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1304

def date
  @date
end

#diskGoogle::Apis::MigrationcenterV1::DailyResourceUsageAggregationDisk

Statistical aggregation of disk usage. Corresponds to the JSON property disk



1309
1310
1311
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1309

def disk
  @disk
end

#memoryGoogle::Apis::MigrationcenterV1::DailyResourceUsageAggregationMemory

Statistical aggregation of memory usage. Corresponds to the JSON property memory



1314
1315
1316
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1314

def memory
  @memory
end

#networkGoogle::Apis::MigrationcenterV1::DailyResourceUsageAggregationNetwork

Statistical aggregation of network usage. Corresponds to the JSON property network



1319
1320
1321
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1319

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1326
1327
1328
1329
1330
1331
1332
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1326

def update!(**args)
  @cpu = args[:cpu] if args.key?(:cpu)
  @date = args[:date] if args.key?(:date)
  @disk = args[:disk] if args.key?(:disk)
  @memory = args[:memory] if args.key?(:memory)
  @network = args[:network] if args.key?(:network)
end