Class: Google::Apis::MigrationcenterV1::DailyResourceUsageAggregationNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Statistical aggregation of network usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyResourceUsageAggregationNetwork

Returns a new instance of DailyResourceUsageAggregationNetwork.



1418
1419
1420
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#egress_bpsGoogle::Apis::MigrationcenterV1::DailyResourceUsageAggregationStats

Statistical aggregation of samples for a single resource usage. Corresponds to the JSON property egressBps



1411
1412
1413
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1411

def egress_bps
  @egress_bps
end

#ingress_bpsGoogle::Apis::MigrationcenterV1::DailyResourceUsageAggregationStats

Statistical aggregation of samples for a single resource usage. Corresponds to the JSON property ingressBps



1416
1417
1418
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1416

def ingress_bps
  @ingress_bps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1423
1424
1425
1426
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 1423

def update!(**args)
  @egress_bps = args[:egress_bps] if args.key?(:egress_bps)
  @ingress_bps = args[:ingress_bps] if args.key?(:ingress_bps)
end