Class: Google::Apis::MigrationcenterV1::ErrorFrame
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::ErrorFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Message representing a frame which failed to be processed due to an error.
Instance Attribute Summary collapse
-
#ingestion_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#original_frame ⇒ Google::Apis::MigrationcenterV1::AssetFrame
Contains data reported from an inventory source on an asset.
-
#violations ⇒ Array<Google::Apis::MigrationcenterV1::FrameViolationEntry>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorFrame
constructor
A new instance of ErrorFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorFrame
Returns a new instance of ErrorFrame.
2235 2236 2237 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingestion_time ⇒ String
Output only. Frame ingestion time.
Corresponds to the JSON property ingestionTime
2218 2219 2220 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2218 def ingestion_time @ingestion_time end |
#name ⇒ String
Output only. The identifier of the ErrorFrame.
Corresponds to the JSON property name
2223 2224 2225 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2223 def name @name end |
#original_frame ⇒ Google::Apis::MigrationcenterV1::AssetFrame
Contains data reported from an inventory source on an asset.
Corresponds to the JSON property originalFrame
2228 2229 2230 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2228 def original_frame @original_frame end |
#violations ⇒ Array<Google::Apis::MigrationcenterV1::FrameViolationEntry>
Output only. All the violations that were detected for the frame.
Corresponds to the JSON property violations
2233 2234 2235 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2233 def violations @violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2240 2241 2242 2243 2244 2245 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2240 def update!(**args) @ingestion_time = args[:ingestion_time] if args.key?(:ingestion_time) @name = args[:name] if args.key?(:name) @original_frame = args[:original_frame] if args.key?(:original_frame) @violations = args[:violations] if args.key?(:violations) end |