Class: Google::Apis::MigrationcenterV1::FileValidationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A resource that aggregates the validation errors found in an import job file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileValidationReport

Returns a new instance of FileValidationReport.



2304
2305
2306
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_errorsArray<Google::Apis::MigrationcenterV1::ImportError>

List of file level errors. Corresponds to the JSON property fileErrors



2286
2287
2288
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2286

def file_errors
  @file_errors
end

#file_nameString

The name of the file. Corresponds to the JSON property fileName

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2291

def file_name
  @file_name
end

#partial_reportBoolean Also known as: partial_report?

Flag indicating that processing was aborted due to maximum number of errors. Corresponds to the JSON property partialReport

Returns:

  • (Boolean)


2296
2297
2298
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2296

def partial_report
  @partial_report
end

#row_errorsArray<Google::Apis::MigrationcenterV1::ImportRowError>

Partial list of rows that encountered validation error. Corresponds to the JSON property rowErrors



2302
2303
2304
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2302

def row_errors
  @row_errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2309
2310
2311
2312
2313
2314
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2309

def update!(**args)
  @file_errors = args[:file_errors] if args.key?(:file_errors)
  @file_name = args[:file_name] if args.key?(:file_name)
  @partial_report = args[:partial_report] if args.key?(:partial_report)
  @row_errors = args[:row_errors] if args.key?(:row_errors)
end