Class: Google::Apis::MigrationcenterV1::FrameViolationEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A resource that contains a single violation of a reported AssetFrame resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrameViolationEntry

Returns a new instance of FrameViolationEntry.



2351
2352
2353
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldString

The field of the original frame where the violation occurred. Corresponds to the JSON property field

Returns:

  • (String)


2344
2345
2346
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2344

def field
  @field
end

#violationString

A message describing the violation. Corresponds to the JSON property violation

Returns:

  • (String)


2349
2350
2351
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2349

def violation
  @violation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2356

def update!(**args)
  @field = args[:field] if args.key?(:field)
  @violation = args[:violation] if args.key?(:violation)
end