Class: Google::Apis::MigrationcenterV1::FstabEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Single fstab entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FstabEntry

Returns a new instance of FstabEntry.



2416
2417
2418
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

The mount point for the filesystem. Corresponds to the JSON property file

Returns:

  • (String)


2388
2389
2390
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2388

def file
  @file
end

#freqFixnum

Used by dump to determine which filesystems need to be dumped. Corresponds to the JSON property freq

Returns:

  • (Fixnum)


2393
2394
2395
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2393

def freq
  @freq
end

#mntopsString

Mount options associated with the filesystem. Corresponds to the JSON property mntops

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2398

def mntops
  @mntops
end

#passnoFixnum

Used by the fsck(8) program to determine the order in which filesystem checks are done at reboot time. Corresponds to the JSON property passno

Returns:

  • (Fixnum)


2404
2405
2406
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2404

def passno
  @passno
end

#specString

The block special device or remote filesystem to be mounted. Corresponds to the JSON property spec

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2409

def spec
  @spec
end

#vfstypeString

The type of the filesystem. Corresponds to the JSON property vfstype

Returns:

  • (String)


2414
2415
2416
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2414

def vfstype
  @vfstype
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2421
2422
2423
2424
2425
2426
2427
2428
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2421

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @freq = args[:freq] if args.key?(:freq)
  @mntops = args[:mntops] if args.key?(:mntops)
  @passno = args[:passno] if args.key?(:passno)
  @spec = args[:spec] if args.key?(:spec)
  @vfstype = args[:vfstype] if args.key?(:vfstype)
end