Class: Google::Apis::MigrationcenterV1::GenericInsight
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::GenericInsight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
A generic insight about an asset.
Instance Attribute Summary collapse
-
#additional_information ⇒ Array<String>
Output only.
-
#default_message ⇒ String
Output only.
-
#message_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenericInsight
constructor
A new instance of GenericInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenericInsight
Returns a new instance of GenericInsight.
2474 2475 2476 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_information ⇒ Array<String>
Output only. Additional information about the insight, each entry can be a
logical entry and must make sense if it is displayed with line breaks between
each entry. Text can contain md style links.
Corresponds to the JSON property additionalInformation
2459 2460 2461 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2459 def additional_information @additional_information end |
#default_message ⇒ String
Output only. In case message_code is not yet known by the client
default_message will be the message to be used instead.
Corresponds to the JSON property defaultMessage
2465 2466 2467 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2465 def @default_message end |
#message_id ⇒ Fixnum
Output only. Represents a globally unique message id for this insight, can be
used for localization purposes, in case message_code is not yet known by the
client use default_message instead.
Corresponds to the JSON property messageId
2472 2473 2474 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2472 def @message_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2479 2480 2481 2482 2483 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2479 def update!(**args) @additional_information = args[:additional_information] if args.key?(:additional_information) @default_message = args[:default_message] if args.key?(:default_message) @message_id = args[:message_id] if args.key?(:message_id) end |