Class: Google::Apis::MigrationcenterV1::GenericPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Generic platform details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenericPlatformDetails

Returns a new instance of GenericPlatformDetails.



2502
2503
2504
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


2493
2494
2495
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2493

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different VMs in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2500

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2507
2508
2509
2510
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2507

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end