Class: Google::Apis::MigrationcenterV1::Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A resource that represents an asset group. The purpose of an asset group is to bundle a set of assets that have something in common, while allowing users to add annotations to the group. An asset can belong to multiple groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Group

Returns a new instance of Group.



2549
2550
2551
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the group was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2522
2523
2524
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2522

def create_time
  @create_time
end

#descriptionString

Optional. The description of the group. Corresponds to the JSON property description

Returns:

  • (String)


2527
2528
2529
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2527

def description
  @description
end

#display_nameString

Optional. User-friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


2532
2533
2534
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2532

def display_name
  @display_name
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2537
2538
2539
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2537

def labels
  @labels
end

#nameString

Output only. The name of the group. Corresponds to the JSON property name

Returns:

  • (String)


2542
2543
2544
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2542

def name
  @name
end

#update_timeString

Output only. The timestamp when the group was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2547
2548
2549
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2547

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2554
2555
2556
2557
2558
2559
2560
2561
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2554

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end