Class: Google::Apis::MigrationcenterV1::ImportDataFile
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::ImportDataFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
A resource that represents a payload file in an import job.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#format ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#upload_file_info ⇒ Google::Apis::MigrationcenterV1::UploadFileInfo
A resource that contains a URI to which a data file can be uploaded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportDataFile
constructor
A new instance of ImportDataFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportDataFile
Returns a new instance of ImportDataFile.
2857 2858 2859 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the file was created.
Corresponds to the JSON property createTime
2830 2831 2832 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2830 def create_time @create_time end |
#display_name ⇒ String
Optional. User-friendly display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
2835 2836 2837 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2835 def display_name @display_name end |
#format ⇒ String
Required. The payload format.
Corresponds to the JSON property format
2840 2841 2842 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2840 def format @format end |
#name ⇒ String
Output only. The name of the file.
Corresponds to the JSON property name
2845 2846 2847 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2845 def name @name end |
#state ⇒ String
Output only. The state of the import data file.
Corresponds to the JSON property state
2850 2851 2852 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2850 def state @state end |
#upload_file_info ⇒ Google::Apis::MigrationcenterV1::UploadFileInfo
A resource that contains a URI to which a data file can be uploaded.
Corresponds to the JSON property uploadFileInfo
2855 2856 2857 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2855 def upload_file_info @upload_file_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2862 2863 2864 2865 2866 2867 2868 2869 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2862 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @format = args[:format] if args.key?(:format) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @upload_file_info = args[:upload_file_info] if args.key?(:upload_file_info) end |