Class: Google::Apis::MigrationcenterV1::ImportJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A resource that represents the background job that imports asset frames.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportJob

Returns a new instance of ImportJob.



2951
2952
2953
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_sourceString

Required. Reference to a source. Corresponds to the JSON property assetSource

Returns:

  • (String)


2904
2905
2906
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2904

def asset_source
  @asset_source
end

#complete_timeString

Output only. The timestamp when the import job was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


2909
2910
2911
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2909

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp when the import job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2914
2915
2916
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2914

def create_time
  @create_time
end

#display_nameString

Optional. User-friendly display name. Maximum length is 256 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


2919
2920
2921
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2919

def display_name
  @display_name
end

#execution_reportGoogle::Apis::MigrationcenterV1::ExecutionReport

A resource that reports result of the import job execution. Corresponds to the JSON property executionReport



2924
2925
2926
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2924

def execution_report
  @execution_report
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2929
2930
2931
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2929

def labels
  @labels
end

#nameString

Output only. The full name of the import job. Corresponds to the JSON property name

Returns:

  • (String)


2934
2935
2936
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2934

def name
  @name
end

#stateString

Output only. The state of the import job. Corresponds to the JSON property state

Returns:

  • (String)


2939
2940
2941
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2939

def state
  @state
end

#update_timeString

Output only. The timestamp when the import job was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2944
2945
2946
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2944

def update_time
  @update_time
end

#validation_reportGoogle::Apis::MigrationcenterV1::ValidationReport

A resource that aggregates errors across import job files. Corresponds to the JSON property validationReport



2949
2950
2951
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2949

def validation_report
  @validation_report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2956

def update!(**args)
  @asset_source = args[:asset_source] if args.key?(:asset_source)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @execution_report = args[:execution_report] if args.key?(:execution_report)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @validation_report = args[:validation_report] if args.key?(:validation_report)
end