Class: Google::Apis::MigrationcenterV1::ListPreferenceSetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::ListPreferenceSetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Response message for listing preference sets.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#preference_sets ⇒ Array<Google::Apis::MigrationcenterV1::PreferenceSet>
The list of PreferenceSets Corresponds to the JSON property
preferenceSets. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPreferenceSetsResponse
constructor
A new instance of ListPreferenceSetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPreferenceSetsResponse
Returns a new instance of ListPreferenceSetsResponse.
3441 3442 3443 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3429 3430 3431 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3429 def next_page_token @next_page_token end |
#preference_sets ⇒ Array<Google::Apis::MigrationcenterV1::PreferenceSet>
The list of PreferenceSets
Corresponds to the JSON property preferenceSets
3434 3435 3436 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3434 def preference_sets @preference_sets end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3439 3440 3441 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3439 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3446 3447 3448 3449 3450 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3446 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @preference_sets = args[:preference_sets] if args.key?(:preference_sets) @unreachable = args[:unreachable] if args.key?(:unreachable) end |