Class: Google::Apis::MigrationcenterV1::MachinePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

The type of machines to consider when calculating virtual machine migration insights and recommendations. Not all machine types are available in all zones and regions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachinePreferences

Returns a new instance of MachinePreferences.



3858
3859
3860
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_machine_seriesArray<Google::Apis::MigrationcenterV1::MachineSeries>

Compute Engine machine series to consider for insights and recommendations. If empty, no restriction is applied on the machine series. Corresponds to the JSON property allowedMachineSeries



3856
3857
3858
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3856

def allowed_machine_series
  @allowed_machine_series
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3863
3864
3865
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3863

def update!(**args)
  @allowed_machine_series = args[:allowed_machine_series] if args.key?(:allowed_machine_series)
end