Class: Google::Apis::MigrationcenterV1::PhysicalPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Platform specific details for Physical Machines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhysicalPlatformDetails

Returns a new instance of PhysicalPlatformDetails.



4703
4704
4705
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


4694
4695
4696
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4694

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different machines in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


4701
4702
4703
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4701

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4708
4709
4710
4711
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4708

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end