Class: Google::Apis::MigrationcenterV1::PreferenceSet
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::PreferenceSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
The preferences that apply to all assets in a given context.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the preference set.
-
#display_name ⇒ String
User-friendly display name.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#virtual_machine_preferences ⇒ Google::Apis::MigrationcenterV1::VirtualMachinePreferences
VirtualMachinePreferences enables you to create sets of assumptions, for example, a geographical location and pricing track, for your migrated virtual machines.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreferenceSet
constructor
A new instance of PreferenceSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreferenceSet
Returns a new instance of PreferenceSet.
4958 4959 4960 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the preference set was created.
Corresponds to the JSON property createTime
4928 4929 4930 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4928 def create_time @create_time end |
#description ⇒ String
A description of the preference set.
Corresponds to the JSON property description
4933 4934 4935 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4933 def description @description end |
#display_name ⇒ String
User-friendly display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
4938 4939 4940 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4938 def display_name @display_name end |
#name ⇒ String
Output only. Name of the preference set.
Corresponds to the JSON property name
4943 4944 4945 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4943 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the preference set was last updated.
Corresponds to the JSON property updateTime
4948 4949 4950 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4948 def update_time @update_time end |
#virtual_machine_preferences ⇒ Google::Apis::MigrationcenterV1::VirtualMachinePreferences
VirtualMachinePreferences enables you to create sets of assumptions, for
example, a geographical location and pricing track, for your migrated virtual
machines. The set of preferences influence recommendations for migrating
virtual machine assets.
Corresponds to the JSON property virtualMachinePreferences
4956 4957 4958 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4956 def virtual_machine_preferences @virtual_machine_preferences end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4963 4964 4965 4966 4967 4968 4969 4970 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 4963 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @virtual_machine_preferences = args[:virtual_machine_preferences] if args.key?(:virtual_machine_preferences) end |