Class: Google::Apis::MigrationcenterV1::RemoveAssetsFromGroupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A request to remove assets from a group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveAssetsFromGroupRequest

Returns a new instance of RemoveAssetsFromGroupRequest.



5069
5070
5071
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. When this value is set to false and one of the given assets is not an existing member of the group, the operation fails with a Not Found error. When set to true this situation is silently ignored by the server. Default value is false. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


5047
5048
5049
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5047

def allow_missing
  @allow_missing
end

#assetsGoogle::Apis::MigrationcenterV1::AssetList

Lists the asset IDs of all assets. Corresponds to the JSON property assets



5053
5054
5055
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5053

def assets
  @assets
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


5067
5068
5069
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5067

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5074
5075
5076
5077
5078
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5074

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @assets = args[:assets] if args.key?(:assets)
  @request_id = args[:request_id] if args.key?(:request_id)
end