Class: Google::Apis::MigrationcenterV1::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Report represents a point-in-time rendering of the ReportConfig results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



5126
5127
5128
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


5088
5089
5090
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5088

def create_time
  @create_time
end

#descriptionString

Free-text description. Corresponds to the JSON property description

Returns:

  • (String)


5093
5094
5095
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5093

def description
  @description
end

#display_nameString

User-friendly display name. Maximum length is 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


5098
5099
5100
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5098

def display_name
  @display_name
end

#nameString

Output only. Name of resource. Corresponds to the JSON property name

Returns:

  • (String)


5103
5104
5105
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5103

def name
  @name
end

#stateString

Report creation state. Corresponds to the JSON property state

Returns:

  • (String)


5108
5109
5110
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5108

def state
  @state
end

#summaryGoogle::Apis::MigrationcenterV1::ReportSummary

Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report. Corresponds to the JSON property summary



5114
5115
5116
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5114

def summary
  @summary
end

#typeString

Report type. Corresponds to the JSON property type

Returns:

  • (String)


5119
5120
5121
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5119

def type
  @type
end

#update_timeString

Output only. Last update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


5124
5125
5126
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5124

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5131

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @summary = args[:summary] if args.key?(:summary)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end