Class: Google::Apis::MigrationcenterV1::ReportSummaryGroupFinding
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::ReportSummaryGroupFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Summary Findings for a specific Group.
Instance Attribute Summary collapse
-
#asset_aggregate_stats ⇒ Google::Apis::MigrationcenterV1::ReportSummaryAssetAggregateStats
Aggregate statistics for a collection of assets.
-
#description ⇒ String
Description for the Group.
-
#display_name ⇒ String
Display Name for the Group.
-
#overlapping_asset_count ⇒ Fixnum
This field is deprecated, do not rely on it having a value.
-
#preference_set_findings ⇒ Array<Google::Apis::MigrationcenterV1::ReportSummaryGroupPreferenceSetFinding>
Findings for each of the PreferenceSets for this group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummaryGroupFinding
constructor
A new instance of ReportSummaryGroupFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummaryGroupFinding
Returns a new instance of ReportSummaryGroupFinding.
5451 5452 5453 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_aggregate_stats ⇒ Google::Apis::MigrationcenterV1::ReportSummaryAssetAggregateStats
Aggregate statistics for a collection of assets.
Corresponds to the JSON property assetAggregateStats
5429 5430 5431 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5429 def asset_aggregate_stats @asset_aggregate_stats end |
#description ⇒ String
Description for the Group.
Corresponds to the JSON property description
5434 5435 5436 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5434 def description @description end |
#display_name ⇒ String
Display Name for the Group.
Corresponds to the JSON property displayName
5439 5440 5441 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5439 def display_name @display_name end |
#overlapping_asset_count ⇒ Fixnum
This field is deprecated, do not rely on it having a value.
Corresponds to the JSON property overlappingAssetCount
5444 5445 5446 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5444 def overlapping_asset_count @overlapping_asset_count end |
#preference_set_findings ⇒ Array<Google::Apis::MigrationcenterV1::ReportSummaryGroupPreferenceSetFinding>
Findings for each of the PreferenceSets for this group.
Corresponds to the JSON property preferenceSetFindings
5449 5450 5451 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5449 def preference_set_findings @preference_set_findings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5456 5457 5458 5459 5460 5461 5462 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5456 def update!(**args) @asset_aggregate_stats = args[:asset_aggregate_stats] if args.key?(:asset_aggregate_stats) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @overlapping_asset_count = args[:overlapping_asset_count] if args.key?(:overlapping_asset_count) @preference_set_findings = args[:preference_set_findings] if args.key?(:preference_set_findings) end |