Class: Google::Apis::MigrationcenterV1::ReportSummaryGroupPreferenceSetFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

Summary Findings for a specific Group/PreferenceSet combination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryGroupPreferenceSetFinding

Returns a new instance of ReportSummaryGroupPreferenceSetFinding.



5532
5533
5534
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compute_engine_findingGoogle::Apis::MigrationcenterV1::ReportSummaryComputeEngineFinding

A set of findings that applies to assets destined for Compute Engine. Corresponds to the JSON property computeEngineFinding



5472
5473
5474
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5472

def compute_engine_finding
  @compute_engine_finding
end

#descriptionString

Description for the Preference Set. Corresponds to the JSON property description

Returns:

  • (String)


5477
5478
5479
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5477

def description
  @description
end

#display_nameString

Display Name of the Preference Set Corresponds to the JSON property displayName

Returns:

  • (String)


5482
5483
5484
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5482

def display_name
  @display_name
end

#machine_preferencesGoogle::Apis::MigrationcenterV1::VirtualMachinePreferences

VirtualMachinePreferences enables you to create sets of assumptions, for example, a geographical location and pricing track, for your migrated virtual machines. The set of preferences influence recommendations for migrating virtual machine assets. Corresponds to the JSON property machinePreferences



5490
5491
5492
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5490

def machine_preferences
  @machine_preferences
end

#monthly_cost_computeGoogle::Apis::MigrationcenterV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostCompute



5495
5496
5497
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5495

def monthly_cost_compute
  @monthly_cost_compute
end

#monthly_cost_network_egressGoogle::Apis::MigrationcenterV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostNetworkEgress



5500
5501
5502
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5500

def monthly_cost_network_egress
  @monthly_cost_network_egress
end

#monthly_cost_os_licenseGoogle::Apis::MigrationcenterV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostOsLicense



5505
5506
5507
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5505

def monthly_cost_os_license
  @monthly_cost_os_license
end

#monthly_cost_otherGoogle::Apis::MigrationcenterV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostOther



5510
5511
5512
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5510

def monthly_cost_other
  @monthly_cost_other
end

#monthly_cost_storageGoogle::Apis::MigrationcenterV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostStorage



5515
5516
5517
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5515

def monthly_cost_storage
  @monthly_cost_storage
end

#monthly_cost_totalGoogle::Apis::MigrationcenterV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostTotal



5520
5521
5522
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5520

def monthly_cost_total
  @monthly_cost_total
end

#sole_tenant_findingGoogle::Apis::MigrationcenterV1::ReportSummarySoleTenantFinding

A set of findings that applies to assets destined for Sole-Tenant nodes. Corresponds to the JSON property soleTenantFinding



5525
5526
5527
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5525

def sole_tenant_finding
  @sole_tenant_finding
end

#vmware_engine_findingGoogle::Apis::MigrationcenterV1::ReportSummaryVmwareEngineFinding

A set of findings that applies to assets destined for VMWare Engine. Corresponds to the JSON property vmwareEngineFinding



5530
5531
5532
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5530

def vmware_engine_finding
  @vmware_engine_finding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
5548
5549
5550
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5537

def update!(**args)
  @compute_engine_finding = args[:compute_engine_finding] if args.key?(:compute_engine_finding)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @machine_preferences = args[:machine_preferences] if args.key?(:machine_preferences)
  @monthly_cost_compute = args[:monthly_cost_compute] if args.key?(:monthly_cost_compute)
  @monthly_cost_network_egress = args[:monthly_cost_network_egress] if args.key?(:monthly_cost_network_egress)
  @monthly_cost_os_license = args[:monthly_cost_os_license] if args.key?(:monthly_cost_os_license)
  @monthly_cost_other = args[:monthly_cost_other] if args.key?(:monthly_cost_other)
  @monthly_cost_storage = args[:monthly_cost_storage] if args.key?(:monthly_cost_storage)
  @monthly_cost_total = args[:monthly_cost_total] if args.key?(:monthly_cost_total)
  @sole_tenant_finding = args[:sole_tenant_finding] if args.key?(:sole_tenant_finding)
  @vmware_engine_finding = args[:vmware_engine_finding] if args.key?(:vmware_engine_finding)
end