Class: Google::Apis::MigrationcenterV1::ReportSummaryHistogramChartDataBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A histogram bucket with a lower and upper bound, and a count of items with a field value between those bounds. The lower bound is inclusive and the upper bound is exclusive. Lower bound may be -infinity and upper bound may be infinity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryHistogramChartDataBucket

Returns a new instance of ReportSummaryHistogramChartDataBucket.



5598
5599
5600
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Count of items in the bucket. Corresponds to the JSON property count

Returns:

  • (Fixnum)


5586
5587
5588
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5586

def count
  @count
end

#lower_boundFixnum

Lower bound - inclusive. Corresponds to the JSON property lowerBound

Returns:

  • (Fixnum)


5591
5592
5593
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5591

def lower_bound
  @lower_bound
end

#upper_boundFixnum

Upper bound - exclusive. Corresponds to the JSON property upperBound

Returns:

  • (Fixnum)


5596
5597
5598
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5596

def upper_bound
  @upper_bound
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5603
5604
5605
5606
5607
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5603

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @lower_bound = args[:lower_bound] if args.key?(:lower_bound)
  @upper_bound = args[:upper_bound] if args.key?(:upper_bound)
end