Class: Google::Apis::MigrationcenterV1::ReportSummaryVmwareEngineFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A set of findings that applies to assets destined for VMWare Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryVmwareEngineFinding

Returns a new instance of ReportSummaryVmwareEngineFinding.



5744
5745
5746
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_asset_countFixnum

Count of assets which are allocated Corresponds to the JSON property allocatedAssetCount

Returns:

  • (Fixnum)


5732
5733
5734
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5732

def allocated_asset_count
  @allocated_asset_count
end

#allocated_regionsArray<String>

Set of regions in which the assets were allocated Corresponds to the JSON property allocatedRegions

Returns:

  • (Array<String>)


5737
5738
5739
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5737

def allocated_regions
  @allocated_regions
end

#node_allocationsArray<Google::Apis::MigrationcenterV1::ReportSummaryVmwareNodeAllocation>

Set of per-nodetype allocation records Corresponds to the JSON property nodeAllocations



5742
5743
5744
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5742

def node_allocations
  @node_allocations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5749
5750
5751
5752
5753
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5749

def update!(**args)
  @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count)
  @allocated_regions = args[:allocated_regions] if args.key?(:allocated_regions)
  @node_allocations = args[:node_allocations] if args.key?(:node_allocations)
end