Class: Google::Apis::MigrationcenterV1::Source
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::Source
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Source represents an object from which asset information is streamed to Migration Center.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Free-text description.
-
#display_name ⇒ String
User-friendly display name.
-
#error_frame_count ⇒ Fixnum
Output only.
-
#managed ⇒ Boolean
(also: #managed?)
If
true, the source is managed by other service(s). -
#name ⇒ String
Output only.
-
#pending_frame_count ⇒ Fixnum
Output only.
-
#priority ⇒ Fixnum
The information confidence of the source.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Data source type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
6282 6283 6284 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the source was created.
Corresponds to the JSON property createTime
6227 6228 6229 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6227 def create_time @create_time end |
#description ⇒ String
Free-text description.
Corresponds to the JSON property description
6232 6233 6234 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6232 def description @description end |
#display_name ⇒ String
User-friendly display name.
Corresponds to the JSON property displayName
6237 6238 6239 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6237 def display_name @display_name end |
#error_frame_count ⇒ Fixnum
Output only. The number of frames that were reported by the source and
contained errors.
Corresponds to the JSON property errorFrameCount
6243 6244 6245 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6243 def error_frame_count @error_frame_count end |
#managed ⇒ Boolean Also known as: managed?
If true, the source is managed by other service(s).
Corresponds to the JSON property managed
6248 6249 6250 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6248 def managed @managed end |
#name ⇒ String
Output only. The full name of the source.
Corresponds to the JSON property name
6254 6255 6256 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6254 def name @name end |
#pending_frame_count ⇒ Fixnum
Output only. Number of frames that are still being processed.
Corresponds to the JSON property pendingFrameCount
6259 6260 6261 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6259 def pending_frame_count @pending_frame_count end |
#priority ⇒ Fixnum
The information confidence of the source. The higher the value, the higher the
confidence.
Corresponds to the JSON property priority
6265 6266 6267 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6265 def priority @priority end |
#state ⇒ String
Output only. The state of the source.
Corresponds to the JSON property state
6270 6271 6272 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6270 def state @state end |
#type ⇒ String
Data source type.
Corresponds to the JSON property type
6275 6276 6277 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6275 def type @type end |
#update_time ⇒ String
Output only. The timestamp when the source was last updated.
Corresponds to the JSON property updateTime
6280 6281 6282 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6280 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6287 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @error_frame_count = args[:error_frame_count] if args.key?(:error_frame_count) @managed = args[:managed] if args.key?(:managed) @name = args[:name] if args.key?(:name) @pending_frame_count = args[:pending_frame_count] if args.key?(:pending_frame_count) @priority = args[:priority] if args.key?(:priority) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |