Class: Google::Apis::MigrationcenterV1::UploadFileInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

A resource that contains a URI to which a data file can be uploaded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadFileInfo

Returns a new instance of UploadFileInfo.



6539
6540
6541
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,String>

Output only. The headers that were used to sign the URI. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


6527
6528
6529
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6527

def headers
  @headers
end

#signed_uriString

Output only. Upload URI for the file. Corresponds to the JSON property signedUri

Returns:

  • (String)


6532
6533
6534
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6532

def signed_uri
  @signed_uri
end

#uri_expiration_timeString

Output only. Expiration time of the upload URI. Corresponds to the JSON property uriExpirationTime

Returns:

  • (String)


6537
6538
6539
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6537

def uri_expiration_time
  @uri_expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6544
6545
6546
6547
6548
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6544

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @signed_uri = args[:signed_uri] if args.key?(:signed_uri)
  @uri_expiration_time = args[:uri_expiration_time] if args.key?(:uri_expiration_time)
end