Class: Google::Apis::MigrationcenterV1::VirtualMachinePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb

Overview

VirtualMachinePreferences enables you to create sets of assumptions, for example, a geographical location and pricing track, for your migrated virtual machines. The set of preferences influence recommendations for migrating virtual machine assets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VirtualMachinePreferences

Returns a new instance of VirtualMachinePreferences.



6652
6653
6654
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitment_planString

Commitment plan to consider when calculating costs for virtual machine insights and recommendations. If you are unsure which value to set, a 3 year commitment plan is often a good value to start with. Corresponds to the JSON property commitmentPlan

Returns:

  • (String)


6616
6617
6618
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6616

def commitment_plan
  @commitment_plan
end

#compute_engine_preferencesGoogle::Apis::MigrationcenterV1::ComputeEnginePreferences

The user preferences relating to Compute Engine target platform. Corresponds to the JSON property computeEnginePreferences



6621
6622
6623
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6621

def compute_engine_preferences
  @compute_engine_preferences
end

#region_preferencesGoogle::Apis::MigrationcenterV1::RegionPreferences

The user preferences relating to target regions. Corresponds to the JSON property regionPreferences



6626
6627
6628
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6626

def region_preferences
  @region_preferences
end

#sizing_optimization_strategyString

Sizing optimization strategy specifies the preferred strategy used when extrapolating usage data to calculate insights and recommendations for a virtual machine. If you are unsure which value to set, a moderate sizing optimization strategy is often a good value to start with. Corresponds to the JSON property sizingOptimizationStrategy

Returns:

  • (String)


6634
6635
6636
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6634

def sizing_optimization_strategy
  @sizing_optimization_strategy
end

#sole_tenancy_preferencesGoogle::Apis::MigrationcenterV1::SoleTenancyPreferences

Preferences concerning Sole Tenancy nodes and VMs. Corresponds to the JSON property soleTenancyPreferences



6639
6640
6641
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6639

def sole_tenancy_preferences
  @sole_tenancy_preferences
end

#target_productString

Target product for assets using this preference set. Specify either target product or business goal, but not both. Corresponds to the JSON property targetProduct

Returns:

  • (String)


6645
6646
6647
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6645

def target_product
  @target_product
end

#vmware_engine_preferencesGoogle::Apis::MigrationcenterV1::VmwareEnginePreferences

The user preferences relating to Google Cloud VMware Engine target platform. Corresponds to the JSON property vmwareEnginePreferences



6650
6651
6652
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6650

def vmware_engine_preferences
  @vmware_engine_preferences
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6657
6658
6659
6660
6661
6662
6663
6664
6665
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6657

def update!(**args)
  @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan)
  @compute_engine_preferences = args[:compute_engine_preferences] if args.key?(:compute_engine_preferences)
  @region_preferences = args[:region_preferences] if args.key?(:region_preferences)
  @sizing_optimization_strategy = args[:sizing_optimization_strategy] if args.key?(:sizing_optimization_strategy)
  @sole_tenancy_preferences = args[:sole_tenancy_preferences] if args.key?(:sole_tenancy_preferences)
  @target_product = args[:target_product] if args.key?(:target_product)
  @vmware_engine_preferences = args[:vmware_engine_preferences] if args.key?(:vmware_engine_preferences)
end