Class: Google::Apis::MigrationcenterV1::DiskUsageSample
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::DiskUsageSample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Disk usage sample. Values are across all disks.
Instance Attribute Summary collapse
-
#average_iops ⇒ Float
Optional.
-
#average_read_iops ⇒ Float
Optional.
-
#average_write_iops ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskUsageSample
constructor
A new instance of DiskUsageSample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskUsageSample
Returns a new instance of DiskUsageSample.
2183 2184 2185 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_iops ⇒ Float
Optional. Average IOPS sampled over a short window. Must be non-negative. If
read or write are set, the sum of read and write will override the value of
the average_iops.
Corresponds to the JSON property averageIops
2169 2170 2171 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2169 def average_iops @average_iops end |
#average_read_iops ⇒ Float
Optional. Average read IOPS sampled over a short window. Must be non-negative.
If both read and write are zero they are ignored.
Corresponds to the JSON property averageReadIops
2175 2176 2177 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2175 def average_read_iops @average_read_iops end |
#average_write_iops ⇒ Float
Optional. Average write IOPS sampled over a short window. Must be non-negative.
If both read and write are zero they are ignored.
Corresponds to the JSON property averageWriteIops
2181 2182 2183 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2181 def average_write_iops @average_write_iops end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2188 2189 2190 2191 2192 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2188 def update!(**args) @average_iops = args[:average_iops] if args.key?(:average_iops) @average_read_iops = args[:average_read_iops] if args.key?(:average_read_iops) @average_write_iops = args[:average_write_iops] if args.key?(:average_write_iops) end |