Class: Google::Apis::MigrationcenterV1::ExecutionReport
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::ExecutionReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
A resource that reports result of the import job execution.
Instance Attribute Summary collapse
-
#execution_errors ⇒ Google::Apis::MigrationcenterV1::ValidationReport
A resource that aggregates errors across import job files.
-
#frames_reported ⇒ Fixnum
Total number of asset frames reported for the import job.
-
#total_rows_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutionReport
constructor
A new instance of ExecutionReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutionReport
Returns a new instance of ExecutionReport.
2267 2268 2269 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_errors ⇒ Google::Apis::MigrationcenterV1::ValidationReport
A resource that aggregates errors across import job files.
Corresponds to the JSON property executionErrors
2255 2256 2257 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2255 def execution_errors @execution_errors end |
#frames_reported ⇒ Fixnum
Total number of asset frames reported for the import job.
Corresponds to the JSON property framesReported
2260 2261 2262 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2260 def frames_reported @frames_reported end |
#total_rows_count ⇒ Fixnum
Output only. Total number of rows in the import job.
Corresponds to the JSON property totalRowsCount
2265 2266 2267 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2265 def total_rows_count @total_rows_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2272 2273 2274 2275 2276 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 2272 def update!(**args) @execution_errors = args[:execution_errors] if args.key?(:execution_errors) @frames_reported = args[:frames_reported] if args.key?(:frames_reported) @total_rows_count = args[:total_rows_count] if args.key?(:total_rows_count) end |