Class: Google::Apis::MigrationcenterV1::Money
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::Money
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Money
constructor
A new instance of Money.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Money
Returns a new instance of Money.
3960 3961 3962 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
3943 3944 3945 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3943 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount. The value must be between -999,999,
999 and +999,999,999 inclusive. If units is positive, nanos must be
positive or zero. If units is zero, nanos can be positive, zero, or
negative. If units is negative, nanos must be negative or zero. For
example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
3952 3953 3954 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3952 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount. For example if currencyCode is "USD", then
1 unit is one US dollar.
Corresponds to the JSON property units
3958 3959 3960 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3958 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3965 3966 3967 3968 3969 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 3965 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |