Class: Google::Apis::MigrationcenterV1::Report
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::Report
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
Report represents a point-in-time rendering of the ReportConfig results.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Free-text description.
-
#display_name ⇒ String
User-friendly display name.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Report creation state.
-
#summary ⇒ Google::Apis::MigrationcenterV1::ReportSummary
Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report.
-
#type ⇒ String
Report type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Report
constructor
A new instance of Report.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Report
Returns a new instance of Report.
5126 5127 5128 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation timestamp.
Corresponds to the JSON property createTime
5088 5089 5090 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5088 def create_time @create_time end |
#description ⇒ String
Free-text description.
Corresponds to the JSON property description
5093 5094 5095 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5093 def description @description end |
#display_name ⇒ String
User-friendly display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
5098 5099 5100 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5098 def display_name @display_name end |
#name ⇒ String
Output only. Name of resource.
Corresponds to the JSON property name
5103 5104 5105 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5103 def name @name end |
#state ⇒ String
Report creation state.
Corresponds to the JSON property state
5108 5109 5110 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5108 def state @state end |
#summary ⇒ Google::Apis::MigrationcenterV1::ReportSummary
Describes the Summary view of a Report, which contains aggregated values for
all the groups and preference sets included in this Report.
Corresponds to the JSON property summary
5114 5115 5116 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5114 def summary @summary end |
#type ⇒ String
Report type.
Corresponds to the JSON property type
5119 5120 5121 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5119 def type @type end |
#update_time ⇒ String
Output only. Last update timestamp.
Corresponds to the JSON property updateTime
5124 5125 5126 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5124 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5131 5132 5133 5134 5135 5136 5137 5138 5139 5140 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 5131 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @summary = args[:summary] if args.key?(:summary) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |