Class: Google::Apis::MigrationcenterV1::VmwareEnginePreferences
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1::VmwareEnginePreferences
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1/classes.rb,
lib/google/apis/migrationcenter_v1/representations.rb,
lib/google/apis/migrationcenter_v1/representations.rb
Overview
The user preferences relating to Google Cloud VMware Engine target platform.
Instance Attribute Summary collapse
-
#commitment_plan ⇒ String
Commitment plan to consider when calculating costs for virtual machine insights and recommendations.
-
#cpu_overcommit_ratio ⇒ Float
CPU overcommit ratio.
-
#memory_overcommit_ratio ⇒ Float
Memory overcommit ratio.
-
#storage_deduplication_compression_ratio ⇒ Float
The Deduplication and Compression ratio is based on the logical (Used Before) space required to store data before applying deduplication and compression, in relation to the physical (Used After) space required after applying deduplication and compression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareEnginePreferences
constructor
A new instance of VmwareEnginePreferences.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareEnginePreferences
Returns a new instance of VmwareEnginePreferences.
6739 6740 6741 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commitment_plan ⇒ String
Commitment plan to consider when calculating costs for virtual machine
insights and recommendations. If you are unsure which value to set, a 3 year
commitment plan is often a good value to start with.
Corresponds to the JSON property commitmentPlan
6715 6716 6717 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6715 def commitment_plan @commitment_plan end |
#cpu_overcommit_ratio ⇒ Float
CPU overcommit ratio. Acceptable values are between 1.0 and 8.0, with 0.1
increment.
Corresponds to the JSON property cpuOvercommitRatio
6721 6722 6723 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6721 def cpu_overcommit_ratio @cpu_overcommit_ratio end |
#memory_overcommit_ratio ⇒ Float
Memory overcommit ratio. Acceptable values are 1.0, 1.25, 1.5, 1.75 and 2.0.
Corresponds to the JSON property memoryOvercommitRatio
6726 6727 6728 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6726 def memory_overcommit_ratio @memory_overcommit_ratio end |
#storage_deduplication_compression_ratio ⇒ Float
The Deduplication and Compression ratio is based on the logical (Used Before)
space required to store data before applying deduplication and compression, in
relation to the physical (Used After) space required after applying
deduplication and compression. Specifically, the ratio is the Used Before
space divided by the Used After space. For example, if the Used Before space
is 3 GB, but the physical Used After space is 1 GB, the deduplication and
compression ratio is 3x. Acceptable values are between 1.0 and 4.0.
Corresponds to the JSON property storageDeduplicationCompressionRatio
6737 6738 6739 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6737 def storage_deduplication_compression_ratio @storage_deduplication_compression_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6744 6745 6746 6747 6748 6749 |
# File 'lib/google/apis/migrationcenter_v1/classes.rb', line 6744 def update!(**args) @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan) @cpu_overcommit_ratio = args[:cpu_overcommit_ratio] if args.key?(:cpu_overcommit_ratio) @memory_overcommit_ratio = args[:memory_overcommit_ratio] if args.key?(:memory_overcommit_ratio) @storage_deduplication_compression_ratio = args[:storage_deduplication_compression_ratio] if args.key?(:storage_deduplication_compression_ratio) end |